import axios from "axios";
export class SegmentTrackingClient {
    constructor(config) {
        this.writeKey = config.trackingWriteKey;
        this.client = axios.create({
            baseURL: config.trackingApiBaseUrl,
            headers: {
                "Content-Type": "application/json",
            },
            timeout: 10000,
            auth: {
                username: config.trackingWriteKey,
                password: "",
            },
        });
    }
    /**
     * Send a track event to Segment
     */
    async track(event) {
        try {
            const payload = {
                ...event,
                type: "track",
                timestamp: event.timestamp || new Date().toISOString(),
                context: {
                    library: {
                        name: "segment-mcp-server",
                        version: "1.0.0",
                    },
                    ...event.context,
                },
            };
            await this.client.post("/track", payload);
        }
        catch (error) {
            throw new Error(`Failed to track event: ${error.message}`);
        }
    }
    /**
     * Send an identify event to Segment
     */
    async identify(event) {
        try {
            const payload = {
                ...event,
                type: "identify",
                timestamp: event.timestamp || new Date().toISOString(),
                context: {
                    library: {
                        name: "segment-mcp-server",
                        version: "1.0.0",
                    },
                    ...event.context,
                },
            };
            await this.client.post("/identify", payload);
        }
        catch (error) {
            throw new Error(`Failed to identify user: ${error.message}`);
        }
    }
    /**
     * Track AI conversation started event
     */
    async trackAIConversationStarted(userId, conversationId, properties = {}, anonymousId) {
        const event = {
            userId,
            anonymousId,
            event: "AI Conversation Started",
            properties: {
                conversation_id: conversationId,
                ...properties,
            },
        };
        await this.track(event);
    }
    /**
     * Track AI conversation ended event
     */
    async trackAIConversationEnded(userId, conversationId, properties = {}, anonymousId) {
        const event = {
            userId,
            anonymousId,
            event: "AI Conversation Ended",
            properties: {
                conversation_id: conversationId,
                ...properties,
            },
        };
        await this.track(event);
    }
    /**
     * Track AI message sent event
     */
    async trackAIMessageSent(userId, conversationId, messageContent, properties = {}, anonymousId) {
        const event = {
            userId,
            anonymousId,
            event: "AI Message Sent",
            properties: {
                conversation_id: conversationId,
                message_content: messageContent,
                ...properties,
            },
        };
        await this.track(event);
    }
    /**
     * Track AI response received event
     */
    async trackAIResponseReceived(userId, conversationId, responseContent, properties = {}, anonymousId) {
        const event = {
            userId,
            anonymousId,
            event: "AI Response Received",
            properties: {
                conversation_id: conversationId,
                response_content: responseContent,
                ...properties,
            },
        };
        await this.track(event);
    }
    /**
     * Track AI feedback event
     */
    async trackAIFeedback(userId, conversationId, messageId, feedbackType, feedbackValue, feedbackText, anonymousId) {
        const event = {
            userId,
            anonymousId,
            event: "AI Feedback Given",
            properties: {
                conversation_id: conversationId,
                message_id: messageId,
                feedback_type: feedbackType,
                feedback_value: feedbackValue,
                feedback_text: feedbackText,
            },
        };
        await this.track(event);
    }
    /**
     * Batch track multiple events
     */
    async batchTrack(events) {
        try {
            const payload = {
                batch: events.map((event) => ({
                    ...event,
                    type: "track",
                    timestamp: event.timestamp || new Date().toISOString(),
                    context: {
                        library: {
                            name: "segment-mcp-server",
                            version: "1.0.0",
                        },
                        ...event.context,
                    },
                })),
            };
            await this.client.post("/batch", payload);
        }
        catch (error) {
            throw new Error(`Failed to batch track events: ${error.message}`);
        }
    }
}
//# sourceMappingURL=tracking-client.js.map