#!/usr/bin/env node
// Core MCP Server exports
export { SegmentMcp } from "./server/segment-mcp.js";
// Transport utilities
export { createStdioTransport } from "./transports/stdio.js";
export { createHttpTransport, createHttpTransportManager, startHttpServer, } from "./transports/http.js";
// Configuration utilities
export { loadConfig, validateConfig } from "./utils/config.js";
export { createLogger } from "./utils/logger.js";
// CLI functionality - only run if this is the main module
async function runCLI() {
    console.error("Starting Segment MCP Server CLI...");
    try {
        const { loadConfig, validateConfig } = await import("./utils/config.js");
        const config = loadConfig();
        validateConfig(config);
        const { SegmentMcp } = await import("./server/segment-mcp.js");
        const server = new SegmentMcp({ config });
        if (config.transport === "stdio") {
            const { createStdioTransport } = await import("./transports/stdio.js");
            const transport = createStdioTransport();
            await server.start(transport);
            console.error("Segment MCP Server connected via stdio and ready to handle requests");
        }
        else if (config.transport === "http") {
            const { createHttpTransportManager } = await import("./transports/http.js");
            const httpManager = createHttpTransportManager(server.getServer(), config);
            await httpManager.start();
            console.error("Segment MCP Server connected via HTTP and ready to handle requests");
            // Handle graceful shutdown for HTTP
            const shutdown = async () => {
                console.error("Shutting down HTTP server...");
                await httpManager.stop();
                process.exit(0);
            };
            process.on("SIGINT", shutdown);
            process.on("SIGTERM", shutdown);
        }
        else {
            throw new Error(`Unsupported transport: ${config.transport}`);
        }
    }
    catch (error) {
        console.error("Failed to start Segment MCP Server:", error);
        console.error("Error stack:", error.stack);
        process.exit(1);
    }
}
// Handle graceful shutdown for stdio mode
process.on("SIGINT", () => {
    console.error("\nShutting down Segment MCP Server...");
    process.exit(0);
});
process.on("SIGTERM", () => {
    console.error("\nShutting down Segment MCP Server...");
    process.exit(0);
});
// Add uncaught exception handler
process.on("uncaughtException", (error) => {
    console.error("Uncaught Exception:", error);
    console.error("Error stack:", error.stack);
    process.exit(1);
});
// Add unhandled rejection handler
process.on("unhandledRejection", (reason, promise) => {
    console.error("Unhandled Rejection at:", promise);
    console.error("Reason:", reason);
    process.exit(1);
});
// Run CLI if this is the main module
if (import.meta.url === `file://${process.argv[1]}`) {
    console.error("Starting CLI mode...");
    runCLI().catch((error) => {
        console.error("Fatal error in CLI:", error);
        console.error("Error stack:", error.stack);
        process.exit(1);
    });
}
//# sourceMappingURL=index.js.map