import { Server } from "@modelcontextprotocol/sdk/server/index.js";
import { CallToolRequestSchema, ListToolsRequestSchema, InitializeRequestSchema, } from "@modelcontextprotocol/sdk/types.js";
import { createLogger } from "../utils/logger.js";
import { SegmentProfileClient } from "../clients/profile-client.js";
import { SegmentTrackingClient } from "../clients/tracking-client.js";
import { createProfileTools, executeProfileTool, } from "../tools/profile-tools.js";
import { createTrackingTools, executeTrackingTool, } from "../tools/tracking-tools.js";
export class SegmentMcp {
    constructor(options) {
        this.config = options.config;
        this.serverName = options.name || "segment-mcp-server";
        this.serverVersion = options.version || "1.0.0";
        this.logger = createLogger(this.config.logLevel);
        this.logger.info("Initializing Segment MCP server...");
        this.logger.info("Creating logger with level:", this.config.logLevel);
        // Initialize clients
        this.logger.info("Initializing Segment clients...");
        this.profileClient = new SegmentProfileClient(this.config);
        this.trackingClient = new SegmentTrackingClient(this.config);
        this.logger.info("Segment clients initialized successfully");
        // Initialize MCP server
        this.logger.info("Initializing MCP server...");
        this.server = new Server({
            name: this.serverName,
            version: this.serverVersion,
        }, {
            capabilities: {
                tools: {},
            },
        });
        this.logger.info("MCP server instance created");
        this.setupHandlers();
        this.logger.info("Segment MCP Server initialized successfully");
    }
    setupHandlers() {
        this.logger.info("Setting up request handlers...");
        // Handle initialization
        this.logger.info("Setting up initialize handler...");
        this.server.setRequestHandler(InitializeRequestSchema, async (request) => {
            this.logger.info("Received initialize request", {
                protocolVersion: request.params.protocolVersion,
                clientInfo: request.params.clientInfo,
            });
            try {
                this.logger.info("Preparing initialize response");
                const response = {
                    protocolVersion: "2024-11-05",
                    capabilities: {
                        tools: {},
                        resources: {},
                        prompts: {},
                    },
                    serverInfo: {
                        name: this.serverName,
                        version: this.serverVersion,
                    },
                };
                this.logger.info("Sending initialize response", { response });
                return response;
            }
            catch (error) {
                this.logger.error("Error in initialize handler", {
                    error: error.message,
                    stack: error.stack,
                });
                throw error;
            }
        });
        this.logger.info("Initialize handler set up successfully");
        // Handle tool listing
        this.server.setRequestHandler(ListToolsRequestSchema, async () => {
            const profileTools = createProfileTools(this.profileClient);
            const trackingTools = createTrackingTools();
            return {
                tools: [...profileTools, ...trackingTools],
            };
        });
        // Handle tool execution
        this.server.setRequestHandler(CallToolRequestSchema, async (request) => {
            const { name, arguments: params } = request.params;
            this.logger.info(`Executing tool: ${name}`, { params });
            try {
                let result;
                // Route to appropriate tool handler
                if (this.isProfileTool(name)) {
                    result = await executeProfileTool(name, params || {}, this.profileClient);
                }
                else if (this.isTrackingTool(name)) {
                    result = await executeTrackingTool(name, params || {}, this.trackingClient);
                }
                else {
                    throw new Error(`Unknown tool: ${name}`);
                }
                this.logger.info(`Tool execution completed: ${name}`, {
                    success: result.success,
                    hasError: !!result.error,
                });
                return {
                    content: [
                        {
                            type: "text",
                            text: JSON.stringify(result, null, 2),
                        },
                    ],
                };
            }
            catch (error) {
                this.logger.error(`Tool execution failed: ${name}`, {
                    error: error.message,
                    stack: error.stack,
                });
                return {
                    content: [
                        {
                            type: "text",
                            text: JSON.stringify({
                                success: false,
                                error: error.message,
                                tool: name,
                            }, null, 2),
                        },
                    ],
                    isError: true,
                };
            }
        });
    }
    isProfileTool(toolName) {
        const profileTools = [
            "get_profile_traits",
            "get_profile_events",
            "get_profile_past_chat",
        ];
        return profileTools.includes(toolName);
    }
    isTrackingTool(toolName) {
        const trackingTools = [
            "track_ai_conversation",
            "track_ai_query",
            "track_ai_feedback",
            "track_custom_event",
            "identify_user",
        ];
        return trackingTools.includes(toolName);
    }
    /**
     * Start the MCP server with the provided transport
     */
    async start(transport) {
        this.logger.info("Starting MCP server with provided transport...");
        try {
            await this.server.connect(transport);
            this.logger.info("Segment MCP Server connected and ready to handle requests");
        }
        catch (error) {
            this.logger.error("Failed to connect server to transport", {
                error: error.message,
                stack: error.stack,
            });
            throw error;
        }
    }
    /**
     * Get the underlying MCP server instance
     */
    getServer() {
        return this.server;
    }
    /**
     * Get the logger instance
     */
    getLogger() {
        return this.logger;
    }
    /**
     * Get the configuration
     */
    getConfig() {
        return this.config;
    }
}
//# sourceMappingURL=segment-mcp.js.map