import { GetProfileTraitsSchema, GetProfileEventsSchema, GetProfilePastChatSchema, } from "../schemas/profile-schemas.js";
export function createProfileTools(profileClient) {
    return [
        {
            name: "get_profile_traits",
            description: "Get user traits from Segment Profile API using external ID (e.g., email:user@example.com)",
            inputSchema: {
                type: "object",
                properties: {
                    external_id: {
                        type: "string",
                        description: "The external identifier in format type:value (e.g., email:user@example.com)",
                    },
                    space_id: {
                        type: "string",
                        description: "Optional Segment space ID (uses default if not provided)",
                    },
                },
                required: ["external_id"],
            },
        },
        {
            name: "get_profile_events",
            description: "Get user events from Segment Profile API using external ID (e.g., email:user@example.com)",
            inputSchema: {
                type: "object",
                properties: {
                    external_id: {
                        type: "string",
                        description: "The external identifier in format type:value (e.g., email:user@example.com)",
                    },
                    limit: {
                        type: "number",
                        description: "Maximum number of events to return (1-200)",
                        minimum: 1,
                        maximum: 200,
                    },
                    cursor: {
                        type: "string",
                        description: "Cursor for pagination to get next page of events",
                    },
                    space_id: {
                        type: "string",
                        description: "Optional Segment space ID (uses default if not provided)",
                    },
                },
                required: ["external_id"],
            },
        },
        {
            name: "get_profile_past_chat",
            description: "Get user events related to past chat with AI from Segment Profile API using external ID (e.g., email:user@example.com)",
            inputSchema: {
                type: "object",
                properties: {
                    external_id: {
                        type: "string",
                        description: "The external identifier in format type:value (e.g., email:user@example.com)",
                    },
                    limit: {
                        type: "number",
                        description: "Maximum number of events to return (1-200)",
                        minimum: 1,
                        maximum: 200,
                    },
                    cursor: {
                        type: "string",
                        description: "Cursor for pagination to get next page of events",
                    },
                    space_id: {
                        type: "string",
                        description: "Optional Segment space ID (uses default if not provided)",
                    },
                },
                required: ["external_id"],
            },
        },
    ];
}
export async function executeProfileTool(toolName, params, profileClient) {
    try {
        switch (toolName) {
            case "get_profile_traits": {
                const validatedParams = GetProfileTraitsSchema.parse(params);
                const traitsResponse = await profileClient.getProfileTraits(validatedParams.external_id, validatedParams.space_id);
                return {
                    success: true,
                    external_id: validatedParams.external_id,
                    traits: traitsResponse.traits,
                    cursor: traitsResponse.cursor,
                };
            }
            case "get_profile_events": {
                const validatedParams = GetProfileEventsSchema.parse(params);
                const eventsResponse = await profileClient.getProfileEvents(validatedParams.external_id, {
                    limit: validatedParams.limit,
                    cursor: validatedParams.cursor,
                    spaceId: validatedParams.space_id,
                    exclude: "AI Conversation Started,AI Message Sent,AI Response Received,AI Query Executed,AI Feedback Given",
                });
                if (!eventsResponse.data || !Array.isArray(eventsResponse.data)) {
                    throw new Error("No events found for the given profile.");
                }
                return {
                    success: true,
                    external_id: validatedParams.external_id,
                    events: eventsResponse.data,
                    cursor: eventsResponse.cursor,
                    total_events: eventsResponse.data.length,
                };
            }
            case "get_profile_past_chat": {
                const validatedParams = GetProfilePastChatSchema.parse(params);
                const eventsResponse = await profileClient.getProfileEvents(validatedParams.external_id, {
                    limit: validatedParams.limit,
                    cursor: validatedParams.cursor,
                    spaceId: validatedParams.space_id,
                    include: "AI Conversation Started,AI Message Sent,AI Response Received,AI Query Executed,AI Feedback Given",
                });
                if (!eventsResponse.data || !Array.isArray(eventsResponse.data)) {
                    throw new Error("No events found for the given profile.");
                }
                return {
                    success: true,
                    external_id: validatedParams.external_id,
                    events: eventsResponse.data,
                    cursor: eventsResponse.cursor,
                    total_events: eventsResponse.data.length,
                };
            }
            default:
                throw new Error(`Unknown profile tool: ${toolName}`);
        }
    }
    catch (error) {
        return {
            success: false,
            error: error.message,
            tool: toolName,
        };
    }
}
//# sourceMappingURL=profile-tools.js.map